pub struct SessionMetadata {
pub composer_id: String,
pub title: Option<String>,
pub created_at_ms: Option<i64>,
pub updated_at_ms: Option<i64>,
}Expand description
Stable session metadata used by list, stats, and export.
Fields
composer_id: Stringtitle: Option<String>created_at_ms: Option<i64>updated_at_ms: Option<i64>Trait Implementations
Sourceimpl Clone for SessionMetadata
impl Clone for SessionMetadata
Sourcefn clone(&self) -> SessionMetadata
fn clone(&self) -> SessionMetadata
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SessionMetadata
impl Debug for SessionMetadata
Sourceimpl PartialEq for SessionMetadata
impl PartialEq for SessionMetadata
Sourcefn eq(&self, other: &SessionMetadata) -> bool
fn eq(&self, other: &SessionMetadata) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for SessionMetadata
impl StructuralPartialEq for SessionMetadata